@@ -7,30 +7,29 @@ use warnings;
 use Carp;
 use GIS::Distance;
 
+use overload '""' => \&as_string;
+
 =head1 NAME
 
-Geo::Location::Point -
-Location information
+Geo::Location::Point - Location information
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
+Geo::Location::Point stores a place.
+
     use Geo::Location::Point;
 
     my $location = Geo::Location::Point->new();
 
-=head1 DESCRIPTION
-
-Geo::Location::Point stores a place.
-
-=head1 METHODS
+=head1 SUBROUTINES/METHODS
 
 =head2 new
 
@@ -38,8 +37,6 @@ Geo::Location::Point stores a place.
 
 =cut
 
-use Data::Dumper;
-
 sub new {
 	my $proto = shift;
 	my $class = ref($proto) || $proto;
@@ -179,16 +176,16 @@ sub as_string {
 sub _sortoutcase {
 	my $self = shift;
 	my $field = lc(shift);
-	my $ret;
+	my $rc;
 
 	foreach (split(/ /, $field)) {
-		if($ret) {
-			$ret .= ' ';
+		if($rc) {
+			$rc .= ' ';
 		}
-		$ret .= ucfirst($_);
+		$rc .= ucfirst($_);
 	}
 
-	$ret;
+	return $rc;
 }
 
 =head2	attr
@@ -198,6 +195,7 @@ Get/set location attributes, e.g. city
     $location->city('London');
     $location->country('UK');
     print $location->as_string(), "\n";
+    print "$location\n";	# Calls as_string
 
 =cut
 
@@ -234,7 +232,7 @@ L<Geo::Point>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2019 Nigel Horne.
+Copyright 2019-2020 Nigel Horne.
 
 The program code is released under the following licence: GPL2 for personal use on a single computer.
 All other users (including Commercial, Charity, Educational, Government)
